@@ -398,7 +398,7 @@ class SharePointAPI:
 
         return r.json()
 
-    def get_item_versions(self, sharepoint_site, sp_list, item_id) -> list:
+    def get_item_versions(self, sharepoint_site, sp_list, item_id, select_fields=[]) -> list:
         '''
             Returns a list of users from a given sharepoint_site
         '''
@@ -411,8 +411,12 @@ class SharePointAPI:
         else:
             sys.exit(1)
 
-        r = self._api_get_call(
-            f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists(guid\'{guid}\')/items({item_id})/Versions')
+        if select_fields:
+            r = self._api_get_call(
+                f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists(guid\'{guid}\')/items({item_id})/versions?$select={",".join(select_fields)}')
+        else:
+            r = self._api_get_call(
+                f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists(guid\'{guid}\')/items({item_id})/Versions')
 
         versions = r.json()["d"]['results']
         return versions
